@@ -4,7 +4,6 @@ from importlib import import_module
 from types import FunctionType
 
 
-
 # The following code searches for parse functions to allow them to be
 # added to objects as properties using the append_parsers function
 # it also imports them so they are available from `oscn.parse`
@@ -13,13 +12,11 @@ parse_functions = []
 
 try:
     for py_file in listdir(__path__[0]):
-        parse_module = (
-            import_module(f'.{splitext(py_file)[0]}', package=__package__)
-            )
+        parse_module = import_module(f".{splitext(py_file)[0]}", package=__package__)
         for name in dir(parse_module):
             attr = getattr(parse_module, name)
             if isinstance(attr, FunctionType):
-                if hasattr(attr, 'target'):
+                if hasattr(attr, "target"):
                     # replaces 'from .counts import counts'
                     locals()[name] = attr
                     parse_functions.append(attr)
@@ -28,13 +25,14 @@ except NameError:
 
 
 def make_safe_parser(fn):
-    on_error = fn._default_value if hasattr(fn, '_default_value') else False
+    on_error = fn._default_value if hasattr(fn, "_default_value") else False
 
     def safe_parser(self):
         try:
             return fn(self.text)
         except:
             return on_error
+
     return safe_parser
 
 
