@@ -4,11 +4,11 @@ from unicodedata import normalize
 
 def clean_string(some_string):
     # removes escape chars and excess spaces
-    normal_str = normalize('NFKD', some_string)
+    normal_str = normalize("NFKD", some_string)
     # remove line breaks
-    no_lines = re.sub('\\r\\n|\\n\\n', ' ', normal_str)
+    no_lines = re.sub("\\r\\n|\\n\\n", " ", normal_str)
     # reduce spaces
-    condensed = re.sub(' +', ' ', no_lines)
+    condensed = re.sub(" +", " ", no_lines)
     return condensed.strip()
 
 
@@ -17,7 +17,7 @@ def text_values(ResultSet):
 
 
 def column_titles(thead):
-    return [hdr for hdr in map(lambda str:str.lower(), text_values(thead))]
+    return [hdr for hdr in map(lambda str: str.lower(), text_values(thead))]
 
 
 def add_properties(obj, names, values):
@@ -32,14 +32,15 @@ def lists2dict(keys, values):
 def find_values(soup, key_names):
     key_values = []
     for key in key_names:
-        key_found = soup.find(string=re.compile(f'{key}:'))
-        key_value = key_found.split(':')[1] if key_found else ''
+        key_found = soup.find(string=re.compile(f"{key}:"))
+        key_value = key_found.split(":")[1] if key_found else ""
         key_values.append(clean_string(key_value))
     return lists2dict(key_names, key_values)
 
+
 # class to allow adding metadata to returned lists
 class MetaList(list):
-    saved_text = ''
+    saved_text = ""
 
     @property
     def text(self):
